==> ejc-lz-impl-3.0.0-20220309.065506-10-sources.jar: com/ejianc/business/base/bean/CustomermanageEntity.java <==
package com.ejianc.business.base.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 客户管理信息
 * 
 * @author generator
 * 
 */
 @TableName("ejc_base_customer_managearchives")
public class CustomermanageEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 客户编码
    @TableField(value="name")
    private String name; // 客户名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="info_id")
    private Long infoId; // 客户基本信息id
    @TableField(value="abbname")
    private String abbname; // 客户简称
    @TableField(value="license_code")
    private String licenseCode; // 营业执照号
    @TableField(value="address")
    private String address; // 地址
    @TableField(value="credit_range")
    private String creditRange; // 信用范围
    @TableField(value="credit_level")
    private String creditLevel; // 信用级别
    @TableField(value="legal_person")
    private String legalPerson; // 法人
    @TableField(value="sales_quota")
    private String salesQuota; // 销售额度
    @TableField(value="remarks")
    private String remarks; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_id")
    private Long changeId; // 变更单据id
    @TableField(value="change_state")
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    
    
    

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getInfoId() {
        return infoId;
    }

    public void setInfoId(Long infoId) {
        this.infoId = infoId;
    }
    public String getAbbname() {
        return abbname;
    }

    public void setAbbname(String abbname) {
        this.abbname = abbname;
    }
    public String getLicenseCode() {
        return licenseCode;
    }

    public void setLicenseCode(String licenseCode) {
        this.licenseCode = licenseCode;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public String getCreditRange() {
        return creditRange;
    }

    public void setCreditRange(String creditRange) {
        this.creditRange = creditRange;
    }
    public String getCreditLevel() {
        return creditLevel;
    }

    public void setCreditLevel(String creditLevel) {
        this.creditLevel = creditLevel;
    }
    public String getLegalPerson() {
        return legalPerson;
    }

    public void setLegalPerson(String legalPerson) {
        this.legalPerson = legalPerson;
    }
    public String getSalesQuota() {
        return salesQuota;
    }

    public void setSalesQuota(String salesQuota) {
        this.salesQuota = salesQuota;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }
    
}

==> ejc-lz-impl-3.0.0-20220411.011057-38-sources.jar: com/ejianc/business/base/bean/CustomermanageEntity.java <==
package com.ejianc.business.base.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 客户管理信息
 * 
 * @author generator
 * 
 */
 @TableName("ejc_base_customer_managearchives")
public class CustomermanageEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 客户编码
    @TableField(value="name")
    private String name; // 客户名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="info_id")
    private Long infoId; // 客户基本信息id
    @TableField(value="abbname")
    private String abbname; // 客户简称
    @TableField(value="license_code")
    private String licenseCode; // 营业执照号
    @TableField(value="address")
    private String address; // 地址
    @TableField(value="credit_range")
    private String creditRange; // 信用范围
    @TableField(value="credit_level")
    private String creditLevel; // 信用级别
    @TableField(value="legal_person")
    private String legalPerson; // 法人
    @TableField(value="sales_quota")
    private String salesQuota; // 销售额度
    @TableField(value="remarks")
    private String remarks; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_id")
    private Long changeId; // 变更单据id
    @TableField(value="change_state")
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="corporate_id_number")
    private String corporateIdNumber; // 法人身份证号
    @TableField(value="corporate_phone")
    private String corporatePhone; // 法人手机号
    @TableField(value="registered_capital")
    private String registeredCapital; // 注册资金
    @TableField(value="category_name")
    private String categoryName; // 客户分类名称
    @TableField(value="category_id")
    private Long categoryId; // 客户分类id
    @TableField(value="org_certificate_code")
    private String orgCertificateCode; // 组织机构证号
    @TableField(value="security_level")
    private Integer securityLevel; // 安全级别:1 一级 2 二级 3 三级
    @TableField(value="hide_flag")
    private Integer hideFlag; // 隐藏标志: 0 显示 1 不显示
    
    
    

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getInfoId() {
        return infoId;
    }

    public void setInfoId(Long infoId) {
        this.infoId = infoId;
    }
    public String getAbbname() {
        return abbname;
    }

    public void setAbbname(String abbname) {
        this.abbname = abbname;
    }
    public String getLicenseCode() {
        return licenseCode;
    }

    public void setLicenseCode(String licenseCode) {
        this.licenseCode = licenseCode;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public String getCreditRange() {
        return creditRange;
    }

    public void setCreditRange(String creditRange) {
        this.creditRange = creditRange;
    }
    public String getCreditLevel() {
        return creditLevel;
    }

    public void setCreditLevel(String creditLevel) {
        this.creditLevel = creditLevel;
    }
    public String getLegalPerson() {
        return legalPerson;
    }

    public void setLegalPerson(String legalPerson) {
        this.legalPerson = legalPerson;
    }
    public String getSalesQuota() {
        return salesQuota;
    }

    public void setSalesQuota(String salesQuota) {
        this.salesQuota = salesQuota;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }

    public String getCorporateIdNumber() {
        return corporateIdNumber;
    }

    public void setCorporateIdNumber(String corporateIdNumber) {
        this.corporateIdNumber = corporateIdNumber;
    }

    public String getCorporatePhone() {
        return corporatePhone;
    }

    public void setCorporatePhone(String corporatePhone) {
        this.corporatePhone = corporatePhone;
    }

    public String getRegisteredCapital() {
        return registeredCapital;
    }

    public void setRegisteredCapital(String registeredCapital) {
        this.registeredCapital = registeredCapital;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public String getOrgCertificateCode() {
        return orgCertificateCode;
    }

    public void setOrgCertificateCode(String orgCertificateCode) {
        this.orgCertificateCode = orgCertificateCode;
    }

    public Integer getSecurityLevel() {
        return securityLevel;
    }

    public void setSecurityLevel(Integer securityLevel) {
        this.securityLevel = securityLevel;
    }

    public Integer getHideFlag() {
        return hideFlag;
    }

    public void setHideFlag(Integer hideFlag) {
        this.hideFlag = hideFlag;
    }
}
